@@ -5,16 +5,10 @@ import re
 import os
 import sys
 
-
-sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
-sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__)))+"/hardrules/")
-
 try:
-    import unicodedata2.unicodedata2 as ucd2
+    from .hardrules import unicodedata2 as ucd2
 except (SystemError, ImportError):
-    import hardrules.unicodedata2 as ucd2
-
-
+    from hardrules import unicodedata2 as ucd2
 
 from unicodedata import category as cat
 from fastspell import FastSpell
@@ -41,7 +35,7 @@ regex_url = regex.compile('((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}
 regex_breadcrumbs1 = regex.compile("([ ][-/][ ]|[<>*]|[ ][:][ ])")
 regex_breadcrumbs2 = regex.compile("([ ][»][ ]|[|→←•·¬])")
 regex_unicode_noise = regex.compile("[\x80-\xFF]{3,}")
-regex_spaces_noise = regex.compile("([ ].){4,}[ ]")
+regex_spaces_noise = regex.compile("([ ]\D){4,}[ ]")
 regex_paren = regex.compile("[][(){}]")
 regex_unwanted = regex.compile("[+*]")
 regex_inconditional = regex.compile("=\"")
@@ -68,6 +62,7 @@ class Hardrules():
     rule_pipeline['length_ratio'] = 2.0
     rule_pipeline['no_identical'] = True
     rule_pipeline['no_literals'] = ["Re:","{{", "%s", "}}", "+++", "***", '=\"']
+    rule_pipeline['no_only_symbols'] = True
     rule_pipeline['no_only_numbers'] = True
     rule_pipeline['no_urls'] = True
     rule_pipeline['no_breadcrumbs'] = True
@@ -127,7 +122,7 @@ class Hardrules():
         self.run_all_rules = args.run_all_rules
         self.disable_minimal_length = args.disable_minimal_length
         self.rules = {n: f for n, f in getmembers(self) if n.startswith('c_')}
-        logging.debug(f"Enabled rules: {self.rules.keys()}")
+        logging.debug(f"Available rules: {self.rules.keys()}")
 
         # Create dict with with config
         self.config = deepcopy(self.rule_pipeline)
@@ -141,6 +136,8 @@ class Hardrules():
             for name, param in args.rules_config.items():
                 self.config[name] = param
 
+        logging.debug(f"Enabled rules: {self.config.keys()}")
+
         # Check that all the rule functions are implemented
         for rule_name in self.config.keys():
             if 'c_' + rule_name not in self.rules:
@@ -173,10 +170,16 @@ class Hardrules():
                     logging.debug(f"Side: {sidename}")
                     logging.debug(f"Keep: {keep}")
                     if not keep and self.run_all_rules:
-                        discards.append(f"{rule_name}({sidename})")
                         # Especial case for empty rule to avoid crashes in other rules
                         if rule_name == 'no_empty':
+                            #check if both are empty:
+                            if left=="":
+                                discards.append("no_empty(left)")
+                            if right=="":
+                                discards.append("no_empty(right)")
                             return discards
+                        else:   
+                            discards.append(f"{rule_name}({sidename})")                            
                     elif not keep:
                         return f"{rule_name}({sidename})"
             else:
@@ -196,8 +199,8 @@ class Hardrules():
     def c_no_empty(self, sentence, side):
         return sentence != ""
 
-    def c_no_titles(self, left, right):
-        return not (left.istitle() and right.istitle())
+    def c_no_titles(self, left, right):    
+        return not ((len(left.strip().split(" ")) > 1 and left.istitle()) and (len(right.strip().split(" ")) > 1 and right.istitle()))
 
     def c_not_too_long(self, sentence, side):
         return len(sentence) < self.config['not_too_long']
@@ -225,7 +228,10 @@ class Hardrules():
     def c_length_ratio(self, left, right):
         lower_ratio = 1/self.config["length_ratio"]
         upper_ratio = self.config["length_ratio"]
-        return lower_ratio <= float(len(left.encode("utf8")))/float(len(right.encode("utf8"))) <= upper_ratio
+        if self.src_lang in CJK or self.trg_lang in CJK:
+            return lower_ratio <= len(left.encode("utf8"))/len(right.encode("utf8")) <= upper_ratio
+        else:
+            return lower_ratio <= len(left)/len(right) <= upper_ratio
 
     def c_no_wrong_language(self, sentence, side='left'):
         if self.fastspell_src is None:
@@ -254,8 +260,8 @@ class Hardrules():
             return False
         return True
 
-    def c_alpha(self, sentence, side):
-        return len(regex_alpha.findall(sentence)) > 0
+    def c_no_only_symbols(self, sentence, side):
+        return len(regex_alpha.findall(sentence)) / len(sentence) > 0.1
 
     def c_no_only_numbers(self, sentence, side):
         lang = self.src_lang if side == 'left' else self.trg_lang
